@@ -152,7 +152,6 @@ namespace Manager {
         if (window != nullptr) {
             glfwDestroyWindow(window);
         }
-//        glfwTerminate();
         for (auto &bm: bams) {
             hts_close(bm);
         }
@@ -162,9 +161,6 @@ namespace Manager {
         for (auto &idx: indexes) {
             hts_idx_destroy(idx);
         }
-//        if (fai != nullptr) {
-//            fai_destroy(fai);
-//        }
     }
 
     void ErrorCallback(int, const char *err_str) {
@@ -786,8 +782,6 @@ namespace Manager {
         }
         int xpos, ypos;
         glfwGetWindowPos(window, &xpos, &ypos);
-//        int windX = fb_width / monitorScale;
-//        int windY = fb_height / monitorScale;
 
         int windX, windY;
         glfwGetWindowSize(window, &windX, &windY);
@@ -951,7 +945,8 @@ namespace Manager {
                 if (mode == Show::SINGLE) {
                     drawScreen();
                 } else if (mode == Show::TILED) {
-                    drawTiles(sSurface->getCanvas(), sContext, sSurface);
+//                    drawTiles(sSurface->getCanvas(), sContext, sSurface);
+                    drawTiles();
                     printIndexInfo();
                 }
             }
@@ -1127,8 +1122,13 @@ namespace Manager {
             totalTabixY = 0;
             tabixY = 0;
         } else {
-            totalTabixY = availableHeight * (float)opts.tab_track_height;
-            tabixY = totalTabixY / nTracks;
+            if (nbams == 0) {
+                totalTabixY = availableHeight;
+                tabixY = totalTabixY / nTracks;
+            } else {
+                totalTabixY = availableHeight * (float) opts.tab_track_height;
+                tabixY = totalTabixY / nTracks;
+            }
         }
         availableHeight -= totalTabixY;
         if (nbams == 0 || opts.max_coverage == 0) {
@@ -1163,7 +1163,7 @@ namespace Manager {
                     yScaling *= 0.95;
                 } else {
                     if (yScaling > 3 * monitorScale) {
-                        pH = yScaling - monitorScale;
+                        pH = yScaling - (monitorScale * opts.read_y_gap);
                     } else {
                         pH = yScaling;
                     }
@@ -1225,6 +1225,10 @@ namespace Manager {
         return false;
     }
 
+    void GwPlot::drawBackground() {
+        rasterCanvas->drawPaint(opts.theme.bgPaint);
+    }
+
     void GwPlot::drawScreen(bool force_buffered_reads) {
 //        std::chrono::high_resolution_clock::time_point initial = std::chrono::high_resolution_clock::now();
         SkCanvas *canvasR = rasterCanvas;
@@ -1365,6 +1369,10 @@ namespace Manager {
         }
     }
 
+    void GwPlot::clearImageCacheQueue() {
+        imageCacheQueue.clear();
+    }
+
     void GwPlot::drawOverlay(SkCanvas *canvas) {
 
         if (!imageCacheQueue.empty()) {
@@ -1651,7 +1659,8 @@ namespace Manager {
         }
     }
 
-    void GwPlot::tileDrawingThread(SkCanvas *canvas, GrDirectContext *sContext, SkSurface *sSurface) {
+//    void GwPlot::tileDrawingThread(SkCanvas *canvas, GrDirectContext *sContext, SkSurface *sSurface) {
+    void GwPlot::tileDrawingThread() {
         currentVarTrack = &variantTracks[variantFileSelection];
         int bStart = currentVarTrack->blockStart;
         int bLen = (int)opts.number.x * (int)opts.number.y;
@@ -1661,10 +1670,12 @@ namespace Manager {
             bool c = imageCache.find(i) != imageCache.end();
             if (!c && i < (int)currentVarTrack->multiRegions.size() && !bams.empty()) {
                 this->regions = currentVarTrack->multiRegions[i];
-                runDrawOnCanvas(canvas);
-                sContext->flush();
-                sk_sp<SkImage> img(sSurface->makeImageSnapshot());
-                imageCache[i] = img;
+//                runDrawOnCanvas(canvas);
+                runDrawOnCanvas(rasterCanvas);
+//                sContext->flush();
+//                sk_sp<SkImage> img(sSurface->makeImageSnapshot());
+//                imageCache[i] = img;
+                imageCache[i] = rasterSurfacePtr[0]->makeImageSnapshot();
             }
         }
     }
@@ -1718,7 +1729,7 @@ namespace Manager {
         }
     }
 
-    void GwPlot::drawTiles(SkCanvas *canvas, GrDirectContext *sContext, SkSurface *sSurface) {
+    void GwPlot::drawTiles() {
         currentVarTrack = &variantTracks[variantFileSelection];
         int bStart = currentVarTrack->blockStart;
 
@@ -1727,7 +1738,7 @@ namespace Manager {
         float y_gap = (variantTracks.size() <= 1) ? 0 : (10 * monitorScale);
         bboxes = Utils::imageBoundingBoxes(opts.number, fb_width, fb_height - 6 * monitorScale, 6 * monitorScale, 6 * monitorScale, y_gap);
         if (currentVarTrack->image_glob.empty()) {
-            tileDrawingThread(canvas, sContext, sSurface);  // draws images from variant file
+            tileDrawingThread();  // draws images from variant file
         } else {
             tileLoadingThread();  // loads static images in .png format
         }
@@ -1747,7 +1758,7 @@ namespace Manager {
             std::rotate(srtLabels.begin(), pivot, pivot + 1);
         }
 
-        canvas->drawPaint(opts.theme.bgPaintTiled);
+        rasterCanvas->drawPaint(opts.theme.bgPaintTiled);
         SkSamplingOptions sampOpts = SkSamplingOptions();
         int i = bStart;
         for (auto &b : bboxes) {
@@ -1768,19 +1779,19 @@ namespace Manager {
                     float newHeight = newWidth / ratio;
                     rect.setXYWH(b.xStart, b.yStart, newWidth, newHeight);
                 }
-                canvas->drawImageRect(imageCache[i], rect, sampOpts);
+                rasterCanvas->drawImageRect(imageCache[i], rect, sampOpts);
                 if (currentVarTrack->multiLabels.empty()) {
                     ++i; continue;
                 }
                 if (i - bStart != mouseOverTileIndex) {
                     currentVarTrack->multiLabels[i].mouseOver = false;
                 }
-                Drawing::drawLabel(opts, canvas, rect, currentVarTrack->multiLabels[i], fonts, seenLabels[fileName], srtLabels);
+                Drawing::drawLabel(opts, rasterCanvas, rect, currentVarTrack->multiLabels[i], fonts, seenLabels[fileName], srtLabels);
             }
             ++i;
         }
-        imageCacheQueue.emplace_back(frameId, sSurface->makeImageSnapshot());
-        sContext->flush();
+        imageCacheQueue.emplace_back(frameId, rasterSurfacePtr[0]->makeImageSnapshot());
+
         glfwSwapBuffers(window);
         redraw = false;
     }
@@ -2156,7 +2167,7 @@ namespace Manager {
 #else
         sk_sp<SkData> png(img->encodeToData());
 #endif
-        if (!png) { return; }
+        if (!png) { std::cerr << "Error: Png creation failed\n"; return; }
         FILE* fout = fopen(path.c_str(), "w");
         fwrite(png->data(), 1, png->size(), fout);
         fclose(fout);
@@ -2192,4 +2203,36 @@ namespace Manager {
         return regions.size();
     }
 
+    // Get terminal size
+//    void GwPlot::getTerminalSize() {
+//        terminal_cols = 80;  // defaults
+//        terminal_rows = 24;
+//        terminal_width_pixels = -1;
+//        terminal_height_pixels = -1;
+//
+//#ifdef G_OS_WIN32
+//        HANDLE chd = GetStdHandle(STD_OUTPUT_HANDLE);
+//        CONSOLE_SCREEN_BUFFER_INFO csb_info;
+//
+//        if (chd != INVALID_HANDLE_VALUE && GetConsoleScreenBufferInfo(chd, &csb_info)) {
+//            terminal_cols = csb_info.srWindow.Right - csb_info.srWindow.Left + 1;
+//            terminal_rows = csb_info.srWindow.Bottom - csb_info.srWindow.Top + 1;
+//        }
+//#else
+//        struct winsize w;
+//        if (ioctl(STDOUT_FILENO, TIOCGWINSZ, &w) >= 0 ||
+//            ioctl(STDERR_FILENO, TIOCGWINSZ, &w) >= 0 ||
+//            ioctl(STDIN_FILENO, TIOCGWINSZ, &w) >= 0) {
+//            terminal_cols = w.ws_col;
+//            terminal_rows = w.ws_row;
+//            terminal_width_pixels = w.ws_xpixel;
+//            terminal_height_pixels = w.ws_ypixel;
+//        }
+//#endif
+//
+//        if (terminal_cols <= 0) terminal_cols = 80;
+//        if (terminal_rows <= 2) terminal_rows = 24;
+//        if (terminal_width_pixels <= 0) terminal_width_pixels = -1;
+//        if (terminal_height_pixels <= 0) terminal_height_pixels = -1;
+//    }
 }
